#!/bin/bash
#set -e
#加载配置信息
function if_err(){
	if [ $? -ne 0 ];then
		exit 127
	fi
}
function install_docker(){
	if which docker >/dev/null; then
  	   echo -e "\033[32m检测到 Docker 已安装，跳过安装步骤\033[0m"
       echo -e "\033[32m启动 Docker\033[0m "
   	   service docker start 2>&1
    else
      echo -e  "\033[32m在线安装 docker\033[0m"
      curl -fsSL https://get.docker.com -o get-docker.sh 2>&1
      sudo sh get-docker.sh --mirror Aliyun 2>&1
      log "\033[32m启动 docker...\033[0m"
      service docker start 2>&1
    fi
}
function install_docker_compose(){
	if which docker-compose >/dev/null; then
   		echo -e "\033[32m检测到 Docker Compose 已安装，跳过安装步骤\033[0m"
    else
      	echo -e  "\033[32m在线安装 docker-compose\033[0m"
        curl -L https://get.daocloud.io/docker/compose/releases/download/1.29.2/docker-compose-`uname -s`-`uname -m` -o /usr/local/bin/docker-compose 2>&1 | tee -a ${__current_dir}/install.log
        chmod +x /usr/local/bin/docker-compose
        ln -s /usr/local/bin/docker-compose /usr/bin/docker-compose
    fi
	# 检查docker-compose是否正
	docker-compose version 1>/dev/null 2>/dev/null
	if [ $? != 0 ];then
   		echo -e "\033[32mdocker-compose 未正常安装，请先安装 docker-compose 后再次执行本脚本\033[0m"
   		exit
	fi
}

echo -e "\033[34m正在检查安装所需环境....\033[0m"
sleep3
#安装Docker
install_docker
if_err
#安装Docker-compose
install_docker_compose
if_err

echo -e "\033[32m*欢迎安装Health-cloud-DB服\033[0m "
sleep 3
echo -e "\033[32m*中间件包括Mysql,MongoDB,Es,Redis,RabbitMQ\033[0m"
sleep 3

source ./install.ini

#定义安装程序的db路径
DB_DEPLOY_FILE=$(dirname $0)/Health-cloud-server/db_server
echo ${DB_DEPLOY_DIR}
if [ ! -d ${DB_DEPLOY_DIR} ];then mkdir -p ${DB_DEPLOY_DIR};fi
#定义部署目标路径(app,db)
db_sc_dir=${DB_DEPLOY_DIR}
#将docker-compose工程部署到本机
cp -rf ${DB_DEPLOY_FILE}/* ${db_sc_dir}/
#创建数据目录
echo -e "正在创建数据目录"
echo "${db_sc_dir}"
mkdir -p ${db_sc_dir}/data/{es_data,mq_data,mongo_data,redis_data,mysql_data}

echo "DB_DEPLOY_DIR=/ops_project/Health-cloud-server-DB">${db_sc_dir}/.env


cd ${db_sc_dir}
source .env
db_compose_file=$PWD/docker-compose-alldb.yaml
docker-compose -f ${db_compose_file} up -d
sleep 3
docker-compose -f ${db_compose_file} ps
if_err

echo -e "\033[32m***Health-cloud-DB中间件已全部安装成功***\033[0m"
echo -e "\033[33m*********安装位置：${db_sc_dir}*****************\033[0m"
echo -e "\033[34m查看服务\033[0m：docker-compose -f ${db_compose_file} ps"
echo -e "\033[34m卸载服务\033[0m：docker-compose -f ${db_compose_file} down"


